import React, {Component} from 'react'
import './bargain-middle-page.scss'
import classnames from 'classnames'
import {HeaderBar, VList} from '@common'
import {Course} from '@common'
import {api, getParam, http} from "@/utils"
import {Toast} from "antd-mobile"
import {Link} from "react-router-dom"
import Ranking from './ranking'

class BargainMiddlePage extends Component {

    constructor(props) {
        super(props)
        this.state = {
            kanjiaIcon: require('./image/kanjia_icon.png'),
            courseList: '',  // 所有砍价课程
            data: '',
            bargainData: '',
            limitPeople: 0,
            outList: [],
            list: [],
            width: '0',
            isShowMore: ''
        }
    }

    componentDidMount() {
        this.getBargainRankList('144', 1)
        this.getBargainCourse()
        this.getBargainInfo()
    }

    // 获取砍价信息
    getBargainInfo = () => {
        http.get(`${api.home}/m/bargain/info?bargaincode=3133332c343739343131&is_originator=1`).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    data: res.data.data,
                    limitPeople: res.data.data.course.limit_people,
                    bargainData: res.data.data.bargain,
                    width: (res.data.data.bargain.bargain_price / res.data.data.bargain.total_price).toFixed(2) * 100 + '%'
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 获取砍价课程
    getBargainCourse = () => {
        http.get(`${api.home}/m/bargain/courseList`).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    courseList: res.data.data
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 获取助理好友
    getBargainRankList = (id, type) => {
        let data = {
            courseId: id,
            type: type
        }
        http.post(`${api.home}/m/bargain/rankList`, data).then((res) => {
            if (res.data.code === 200) {
                let arr = ['刀神', '刀王', '刀霸']
                let newList = res.data.data.out_list.map((item, i) => {
                    return {
                        ...item,
                        rank: arr[i]
                    }
                })
                this.setState({
                    list: res.data.data.list,
                    outList: newList
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }

    // 加入购物车
    toCart = (id) => {
        let data = {
            course_id: id
        }
        http.post(`${api.home}/m/cart/add`, data).then((res) => {
            if (res.data.code === 200 || res.data.code === 15001) {
                this.props.history.push('/shopcart')
            } else {
                Toast.info(res.data.msg, 2);
            }
        })
    }

    // 查看更多
    getMore = () => {
        this.setState({
            isShowMore: true
        })
    }
    // 自组件传给父组件的boxHide
    boxHide = (val) => {
        this.setState({isShowMore: val})
    }


    render() {
        return (
            <div className={'bargain-middle-page'}>
                <HeaderBar title='砍价详情' arrow={true} cart={true}></HeaderBar>
                <div className="top">
                    <div className="bargain-area">
                        <p className='bargain-tip'>你的好友发现一门精品课程，快来一起帮他砍价：</p>
                        <ul>
                            <VList
                                info={<CourseDes data={this.state.data}/>}
                            />
                        </ul>
                        <div className="bargain-detail">
                            <div className="top">
                                <div>
                                    已砍<span className={'reduced-price'}>{this.state.bargainData.bargain_price}元</span>
                                </div>
                                <div>
                                    {/*<span className={'time hour'}>23</span>:*/}
                                    {/*<span className={'time min'}>59</span>:*/}
                                    {/*<span className={'time sec'}>02</span>*/}
                                    {this.state.bargainData.expire_time}
                                    <span className={'inactive'}>后砍价结束</span>
                                </div>
                            </div>
                            <div className="middle">
                                <span style={{width: this.state.width}}></span>
                            </div>
                            <div className="bottom">
                                再邀请<span className={'indicator'}>{this.state.bargainData.invite_num}</span>位好友助力即可获得
                                <span className={'indicator'}>【砍价神器】</span>
                            </div>
                            <div className={'button'}>
                                <button className={'invalid-btn'}>邀请好友砍价</button>
                            </div>
                        </div>
                    </div>
                    <div className="bargain-records">
                        <div className="title">砍价记录</div>
                        <ul>
                            {
                                this.state.outList && this.state.outList.length > 0 && this.state.outList.map((item, index) => {
                                    return (
                                        <li key={index}>
                                            <div className="left">
                                                <img className='avatar' src={item.avatar_file} alt=""/>
                                                <span className={'nickname'}>{item.user_name}</span>
                                                <span className="rank-tag">{item.rank}</span>
                                            </div>
                                            <div className="right">
                                                <img className='kanjia-icon' src={this.state.kanjiaIcon} alt=""/>
                                                砍掉<span className={'price'}>{item.amount}</span>
                                            </div>
                                        </li>
                                    )
                                })

                            }

                        </ul>
                        <div className="more" onClick={this.getMore}>查看更多>></div>
                    </div>
                </div>
                <div className="bargain-course-list">
                    <div className="title-wrapper">
                        <div className="title">我要砍价</div>
                        <div className="subtitle">邀请{this.state.limitPeople}位以上好友帮忙砍价可获得【砍价神器】</div>
                    </div>
                    <ul>
                        {
                            this.state.courseList && this.state.courseList.length > 0 && this.state.courseList.map((item, index) => {
                                return <Course
                                    className={'text-overflow-2'}
                                    key={index}
                                    id={item.course_id}
                                    img={item.image_name}
                                    title={item.course_title}
                                    bottom={<CourseBottom
                                        item={item}
                                        toCart={this.toCart}
                                    />
                                    }
                                />
                            })
                        }
                    </ul>
                </div>
                <Link to={'/preferential'} className={'preferential'}>查看更多精品课程 >></Link>


                {/*更多好友砍价*/}
                <Ranking list={this.state.list} icon={this.state.kanjiaIcon} limitPeople={this.state.limitPeople} isShowMore={this.state.isShowMore} boxHide={this.boxHide}></Ranking>

            </div>
        );
    }
}

function CourseDes(props) {
    const data = props.data && props.data.course
    return (
        <div className={'des'}>
            <div className="course-title text-overflow-2">
                {data.course_title}
            </div>
            <div className="price-bar">
                <span className={'discount-price'}>￥{data.pay_price}</span>
                <span className={'original-price'}>￥{data.course_price}</span>
                <button className={'purchase-btn'}>¥{data.pay_price}去支付</button>
            </div>
        </div>
    )
}

function CourseBottom(props) {
    let Buttons
    if (props.item.bargain_status === 0) {
        Buttons = <button className={'bargain'}>我要砍价</button>
    } else if (props.item.bargain_status === 3) {
        Buttons = <button className={'bargain'}>去学习</button>
    } else {
        Buttons = (
            <div className="btns">
                <button className={classnames('bargain-btn', {
                    invalid: props.item.bargain_status === 2
                })}>{props.item.bargain_status === 2 ? '砍价结束' : '继续砍价'}</button>
                <button onClick={event => props.toCart(props.item.course_id)}
                        className={'purchase-btn'}>¥{props.item.pay_price}去支付
                </button>
            </div>
        )
    }
    return (
        <div className="course-bottom">
            <div className={'course-price'}>
                <span className={'discount-price'}>¥{props.item.price1}</span>
                <span className={'original-price'}>¥{props.item.price0}</span>
            </div>
            {Buttons}
        </div>
    )
}

export default BargainMiddlePage