import React, {Component} from 'react'
import './bargain.scss'
import {Flex, Toast} from "antd-mobile"
import Overlay from '../overlay'
import BargainInfo from './bargainInfo'
import {Link} from "react-router-dom"

import {api, getParam, http} from "@/utils"
import Ranking from "@/components/bargainMiddlePage/ranking"

class Bargain extends Component {
    constructor(props) {
        super(props)
        this.state = {
            isShowOverlay: false,
            kanjiaIcon: require('./image/kanjia_icon.png'),
            info: '',
            outList: [],
            list: [],
            limitPeople: '',
            status: '',
        }
    }

    componentDidMount() {
        this.getBargainInfo()
        this.getBargainRankList('144', 1)
    }

    // 获取助理好友
    getBargainRankList = (id, type) => {
        let data = {
            courseId: id,
            type: type
        }
        http.post(`${api.home}/m/bargain/rankList`, data).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    list: res.data.data.list,
                    outList: res.data.data.out_list[0]
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }


    //获取砍价信息
    getBargainInfo = () => {
        let data = {
            courseId: getParam('id')
        }
        http.post(`${api.home}/m/bargain/courseDetail`, data).then((res) => {
            if (res.data.code === 200) {
                this.setState({
                    info: res.data.data,
                    limitPeople: res.data.data.limit_people
                })
            } else {
                Toast.info(res.data.msg, 2)
            }
        })
    }


    // 查看更多
    getMore = () => {
        this.setState({
            isShowMore: true
        })
    }
    // 自组件传给父组件的boxHide
    boxHide = (val) => {
        this.setState({isShowMore: val})
    }

    // 领取砍价神器
    toArtifact = () => {
        this.setState({
            isShowOverlay: true,
            status: 1,
        })
    }

    // 使用砍价神器
    useArtifact = () => {
        this.setState({
            isShowOverlay: true,
            status: 2,
        })
    }

    // 加入购物车
    toCart = () => {
        let data = {
            course_id: getParam('id')
        }
        http.post(`${api.home}/m/cart/add`, data).then((res) => {
            if (res.data.code === 200 || res.data.code === 15001) {
                this.props.history.push('/shopcart')
            } else {
                Toast.info(res.data.msg, 2);
            }
        })
    }

    // 我要砍价
    iWantBargain = () => {
        //  判断用户是否绑定了手机号



        // this.props.history.push(`/bargain-middle-page?id=${getParam('id')}`)
        this.setState({
            isShowOverlay: true,
            status: 0,
        })
    }

    // 关闭弹窗
    close = () => {
        this.setState({
            isShowOverlay: false,
            status: '',
        })
    }

    render() {
        return (
            <div className={'bargain-func'}>

                {
                    this.state.info.bargain_status === 2 &&
                    <BargainIntro limitPeople={this.state.limitPeople} iWantBargain={this.iWantBargain}/>
                }
                {
                    this.state.info.bargain_status === 0 &&
                    <BargainStatus
                        info={this.state.info}
                        outList={this.state.outList}
                        getMore={this.getMore}
                        toArtifact={this.toArtifact}
                        useArtifact={this.useArtifact}
                    />
                }


                {
                    this.state.isShowOverlay &&
                    <Overlay>
                        {/*绑定手机号*/}
                        {
                            this.state.status === 3 &&
                            <BargainInfo />

                        }
                        {/*砍价成功去分享*/}
                        {
                            this.state.status === 0 &&
                            <BargainSuccess/>
                        }


                        {/*领取砍价神器*/}
                        {
                            this.state.status === 1 &&
                            <Artifact toArtifact={this.toArtifact}/>
                        }
                        {/*使用砍价神器*/}
                        {
                            this.state.status === 2 &&
                            <UseArtifact useArtifact={this.useArtifact} toCart={this.toCart}/>
                        }

                        {
                            this.state.status !== 0 &&
                            <i onClick={this.close} className={'iconfont iconiconfront-2 bargain-close'}></i>
                        }
                    </Overlay>

                }



                {/*更多好友砍价*/}
                <Ranking list={this.state.list} icon={this.state.kanjiaIcon} limitPeople={this.state.limitPeople}
                         isShowMore={this.state.isShowMore} boxHide={this.boxHide}></Ranking>

            </div>
        )
    }
}

function BargainIntro(props) {
    return (
        <div className="intro-outer">
            <div className="intro-inner">
                <Flex direction={'column'} justify={'center'} className={'intro-wrapper'}>
                    <p>
                        邀请
                        <span className={'indicator'}>{props.limitPeople}位</span>
                        好友帮忙砍价可获得
                        <span className={'indicator'}>【砍价神器】</span>
                    </p>
                    <p>一刀绝杀，砍爆底价</p>
                    <Flex.Item>
                        <button onClick={props.iWantBargain}>我要砍价</button>
                    </Flex.Item>
                </Flex>
            </div>
        </div>
    )
}

function BargainStatus(props) {
    let thirdRow, btn
    // is_artifact	 0-再邀请多少人可以使用 1-可以使用未领取 2-已领取 3-已使用
    if (props.info.is_artifact === 0) {
        thirdRow =
            <div>再邀请<span className={'indicator'}>5</span>位好友助力即可获得<span className={'indicator'}>【砍价神器】</span></div>
    } else if (props.info.is_artifact === 1) {
        thirdRow = <div>恭喜你获得<span className={'indicator'}>【砍价神器】</span></div>
        btn = <button onClick={props.toArtifact}>立即领取</button>
    } else if (props.info.is_artifact === 2) {
        thirdRow = <div>恭喜你获得<span className={'indicator'}>【砍价神器】</span></div>
        btn = <button onClick={props.useArtifact}>立即使用</button>
    }

    return (
        <div className="status-outer">

            {
                props.info.bargain_status === 0 &&
                <div className="status-inner">

                    <Flex direction={'column'}>
                        <div className={'first-row'}>
                            <div>
                                已砍<span className={'indicator'}>{props.info.bargain_price}元</span>
                                {/*<span className={'time hour'}>23</span>:*/}
                                {/*<span className={'time min'}>59</span>:*/}
                                {/*<span className={'time sec'}>02</span>*/}
                                {props.info.end_time}
                                后砍价结束
                            </div>
                            <div onClick={props.getMore}>{props.info.assist_num}位好友助力></div>
                        </div>
                        <div className="sec-row">
                            <div>
                                <img
                                    src={props.outList.avatar_file}
                                    alt=""/>
                                <span className='name'>{props.outList.user_name}</span>
                            </div>
                            <div>
                                <div>砍掉<span className={'indicator'}>{props.outList.amount}元</span></div>
                                <button>继续砍价</button>
                            </div>
                        </div>
                        <div className="third-row">
                            {thirdRow}
                            {btn}
                        </div>
                    </Flex>
                </div>
            }

            {
                props.info.bargain_status === 1 &&
                <div className="status-inner status-over">

                    <Flex direction={'column'}>
                        <div className={'first-row'}>
                            <div>
                                已砍<span className={'indicator'}>{props.info.bargain_price}元</span>
                                <span className='bargain-over'>
                                    砍价结束
                                </span>
                            </div>
                            <div onClick={props.getMore}>{props.info.assist_num}位好友助力></div>
                        </div>
                        <div className="time-tobuy">
                            砍价金额将于后清零，请尽快完成支付
                        </div>
                    </Flex>
                </div>
            }
        </div>
    )
}

function BargainSuccess() {
    return (
        <div className="bargain-success">
            <p className={'title'}>
                恭喜你，一刀砍了
                <span className={'indicator'}>39.8元</span>
            </p>
            <p>分享到微信群邀请更多好友帮忙砍价</p>
            <p>
                超过20位好友助力可获得
                <span className={'indicator'} style={{color: '#FF4000'}}>【砍价神器】</span>
                哦
            </p>
        </div>
    )
}

{/*领取砍价神器*/
}

function Artifact(props) {
    return (
        <div className='artifact-box'>
            <p className='top-tip'>恭喜你获得【砍价神器】！</p>
            <p className='middle-tip'>
                您可以使用
                <span className={'indicator'}>【砍价神器】</span>
                再砍一刀
            </p>
            <button className='use-artifact' onClick={props.useArtifact}>立即使用</button>
        </div>
    )
}

function UseArtifact(props) {
    return (
        <div className='use-artifact-box'>
            <p className='top-tip'>厉害了，又砍掉了10元！</p>
            <p className='middle-tip'>
                你已经砍了
                <span className={'indicator'}>109元</span>
                没见过你这么能砍的人...
            </p>
            <p className='btm-tip'>
                不能再砍了哦~
            </p>
            <button className='tubuy' onClick={props.toCart}>去支付</button>
        </div>
    )
}


export default Bargain